#! /bin/csh -f
#===============================================================================
# CVS $Id: atm.setup.csh,v 1.30 2002/05/13 15:59:52 tcraig Exp $
# CVS $Source: /fs/cgd/csm/models/CVS.REPOS/scripts/test.a1/atm.setup.csh,v $
# CVS $Name: ccsm2_0_beta46 $
echo ===========================================================================
echo  atm.setup.csh:  Preparing CAM for execution  `date` 
echo  Purpose:
echo   a. gather or create necessary input files
echo   b. build the CAM, a CCSM active atm component
echo   documentation:  www.ccsm.ucar.edu/models/ccsm2.0
echo ============================================================================

cat $0;$TOOLS/ccsm_checkenvs || exit -1    # check that enviroment variables are set

echo '-------------------------------------------------------------------------'
echo ' (a) gather or create necessary input files in EXEDIR                    '
echo '-------------------------------------------------------------------------'

cd $EXEDIR

# Set restart type
#------------------------------------------------
if ($RUNTYPE == 'startup' ) set NSREST = 0
if ($RUNTYPE == 'continue') set NSREST = 1
if ($RUNTYPE == 'branch')   set NSREST = 3
if ($RUNTYPE == 'hybrid')   set NSREST = 0

# specify physics version:  physics
#------------------------------------------------
set PHYSICS = physics

# input datasets 
#-------------------------
set DATOZON = noaao3.1990.21999.nc
set ABSDATA = abs_ems_factors_fastvx.052001.nc
$TOOLS/ccsm_getinput atm/cam2/ozone/$DATOZON  || exit 99
$TOOLS/ccsm_getinput atm/cam2/rad/$ABSDATA    || exit 99

# Set parameters associated with resolution and find input dataset
#-------------------------

set DYNAMICS = eul
set  NREVSN = ""
set DATINIT = ""

if ($RUNTYPE == 'startup') then
  if ($GRID =~ T85*) set DATINIT = JAN1.T85L26.eul.ccsm.c011015.nc
  if ($GRID =~ T42*) set DATINIT = JAN1.T42L26.eul.ccsm.052001.nc
  if ($GRID =~ T31*) set DATINIT = SEP1.T31L26.c011005.nc
  if ($GRID =~ T21*) set DATINIT = SEP1.T21L26.c011017.nc
  $TOOLS/ccsm_getinput atm/cam2/inic/gaus/$DATINIT || exit 99
  if !($?DATINIT) then
   echo atm: ERROR unsupported resolution/physics/dynamics combination
   exit 2
  endif
endif
if ($RUNTYPE == 'branch') then
  set NREVSN = ${REFCASE}.cam2.r.${REFDATE}-00000
  $TOOLS/ccsm_getfile $REFCASE/atm/rest/$NREVSN || exit 99
endif
if ($RUNTYPE == 'hybrid') then
  set DATINIT = ${REFCASE}.cam2.i.${REFDATE}-00000.nc
  $TOOLS/ccsm_getfile $REFCASE/atm/init/$DATINIT || exit 99
endif


if ($GRID =~ T85*) set PARAMS = (85 256 128 26 .true. .false.  600)
if ($GRID =~ T42*) set PARAMS = (42 128 64 26 .true. .true.  1200)
if ($GRID =~ T31*) set PARAMS = (31  96 48 26 .true. .false. 1800)
if ($GRID =~ T21*) set PARAMS = (21  64 32 18 .true  .false. 2400)

set plon  =  $PARAMS[2]; set plat   = $PARAMS[3]   ; set plev  = $PARAMS[4]
set ptrm  =  $PARAMS[1]; set ptrn   = $PARAMS[1]   ; set ptrk  = $PARAMS[1]
set FLXAVE = $PARAMS[5]; set READTRACE = $PARAMS[6]; set DTIME = $PARAMS[7]

set KMXHDC =  1
if ($GRID =~ T31*) set KMXHDC =  3
if ($GRID =~ T42*  && $plev != 18) set KMXHDC =  5
if ($GRID =~ T85*  && $plev != 18) set KMXHDC =  5

# Create an input namelist file
#------------------------------------------------

set BASEDATE_NUM =  `echo $BASEDATE | sed -e 's/-//g'`  # remove "-"

cat >! atm.stdin << EOF
 &camexp
 caseid      = '$CASE'
 ctitle      = '$CASE $CASESTR'
 ncdata      = '$DATINIT'
 bndtvo      = '$DATOZON'
 nrevsn      = '/$MSSNAME/csm/$REFCASE/atm/rest/$NREVSN'
 absems_data = '$ABSDATA'
 mss_irt     =  $MSSRPD
 mss_wpass   = '$MSSPWD'
 nsrest      =  $NSREST  
 dtime       =  $DTIME 
 start_ymd   =  $BASEDATE_NUM
 linebuf     = .false.
 readtrace   =  $READTRACE
 nelapse     =   -9999    
 ozncyc      = .true.   
 flxave      =  $FLXAVE
 kmxhdc      =  $KMXHDC
 rest_pfile  = '$SCRIPTS/rpointer.$MODEL'
 /
EOF

echo '-------------------------------------------------------------------------'
echo ' (b) Build an executable                                                 '
echo '-------------------------------------------------------------------------'

cd $OBJDIR

# atm source code archive
#------------------------------------------------
set SRCDIR    = $CSMCODE/atm/cam/src
set ATMLNDSHR = $CSMCODE/camclm_share
set MATHUTIL  = mathutil

# Filepath: List of source code directories (in order of importance).
# The cmp command will force a rebuild the old and new files are different
#--------------------------------------------------------------------
\cat >! .tmp << EOF; cmp -s .tmp Filepath || mv -f .tmp Filepath
$SCRIPTS/src.atm
$SRCDIR/dynamics/$DYNAMICS
$SRCDIR/advection/slt
$SRCDIR/control
$SRCDIR/$MATHUTIL
$SRCDIR/$PHYSICS
$ATMLNDSHR
$CSMSHR
$CSMCODE/utils/timing
EOF

# build params.h    (update only if new or changed)
#--------------------------------------------------

\cat >! .tmp << EOF; cmp -s .tmp params.h || mv -f .tmp params.h
#ifndef PARAMS_SET
#define PARAMS_SET
#define PCNST   1
#define PNATS   1
#define PLEV    $plev
#define PLEVR   $plev
#define PLON    $plon
#define PCOLS   $plon
#define PLAT    $plat
#define PTRM    $ptrm
#define PTRN    $ptrn
#define PTRK    $ptrk
#endif
EOF

# build misc.h    (update only if new or changed)
#------------------------------------------------
if ($NTASK == 1)  set SPMD = "#undef  SPMD"
if ($NTASK  > 1)  set SPMD = "#define SPMD"

\cat >! .tmp << EOF; cmp -s .tmp misc.h || mv -f .tmp misc.h
#ifndef MISC_SET
#define MISC_SET
#define COUP_CSM 
$SPMD
#endif
EOF

# Create the executable in EXEDIR/obj
#------------------------------------------------

if ($BLDTYPE == 'true') then
  cc -o makdep $CSMBLD/makdep.c 
  gmake -j 4 -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS MODEL=cam \
      VPFILE=Filepath  EXEC=$EXEDIR/atm || exit 2
else
  echo "BLDTYPE = $BLDTYPE"
endif

echo ==================================================================
echo  End of cam setup shell script
echo ==================================================================
