#! /bin/csh -f
#===============================================================================
# CVS $Id: cpl.setup.csh,v 1.27 2002/05/08 03:04:11 tcraig Exp $
# CVS $Source: /fs/cgd/csm/models/CVS.REPOS/scripts/test.a1/cpl.setup.csh,v $
# CVS $Name: ccsm2_0_beta46 $
#===============================================================================
# cpl.setup.csh: Preparing a CSM coupler, cpl5, for execution
# 
# (a) set environment variables, preposition input data files
# (b) create the namelist input file
# (b) build this component executable
#
# For help, see:  www.ccsm.ucar.edu/models/ccsm2.0
#===============================================================================

cat $0;$TOOLS/ccsm_checkenvs || exit -1            # cat this file, check envs

echo ---------------------------------------------------------------------------
echo  a. set environment variables, preposition input data files             
echo ---------------------------------------------------------------------------

if ($GRID =~  T21*   ) set ATM =  (   T21  64  32 ) # name, x dimension, y dimension
if ($GRID =~  T31*   ) set ATM =  (   T31  96  48 )
if ($GRID =~  T42*   ) set ATM =  (   T42 128  64 )
if ($GRID =~  T62*   ) set ATM =  (   T62 192  94 )
if ($GRID =~  T85*   ) set ATM =  (   T85 256 128 )
if ($GRID =~  *gx3   ) set OCN =  (   gx3 100 116 )
if ($GRID =~  *gx1v3 ) set OCN =  ( gx1v3 320 384 )

if (!($?ATM) || !($?OCN)) echo  'unknown GRID = ' $GRID 
if (!($?ATM) || !($?OCN)) exit -1

\rm -f map_*2*.nc

if ($GRID == T42_gx1v3) then
 set MAP_A2OF_FILE = map_T42_to_gx1v3_aave_da_010709.nc
 set MAP_A2OS_FILE = map_T42_to_gx1v3_bilin_da_010710.nc
 set MAP_O2AF_FILE = map_gx1v3_to_T42_aave_da_010709.nc
 set MAP_R2O_FILE  = map_r05_to_gx1v3_roff_smooth_010718.nc
else if ($GRID == T31_gx3) then
 set MAP_A2OF_FILE = map_T31_to_gx3_aave_da_010327.nc
 set MAP_A2OS_FILE = map_T31_to_gx3_bilin_da_010327.nc
 set MAP_O2AF_FILE = map_gx3_to_T31_aave_da_010327.nc
 set MAP_R2O_FILE  = map_r05_to_gx3_roffb_b6b.c010608.nc
else if ($GRID == T31_gx1v3) then
 set MAP_A2OF_FILE = map_T31_to_gx1v3_aave_da_020103.nc
 set MAP_A2OS_FILE = map_T31_to_gx1v3_bilin_da_020103.nc
 set MAP_O2AF_FILE = map_gx1v3_to_T31_aave_da_020103.nc
 set MAP_R2O_FILE  = map_r05_to_gx1v3_roff_smooth_010718.nc
else if ($GRID == T42_gx3) then
 set MAP_A2OF_FILE = map_T42_to_gx3_aave_da_990723.nc
 set MAP_A2OS_FILE = map_T42_to_gx3_bilin_da_990723.nc
 set MAP_O2AF_FILE = map_gx3_to_T42_aave_da_990723.nc
 set MAP_R2O_FILE  = map_r05_to_gx3_roffb_b6b.c010608.nc
else if ($GRID == T62_gx1v3) then
 set MAP_A2OF_FILE = map_T62_to_gx1v3_aave_da_010806.nc
 set MAP_A2OS_FILE = map_T62_to_gx1v3_bilin_da_010806.nc
 set MAP_O2AF_FILE = map_gx1v3_to_T62_aave_da_010806.nc
 set MAP_R2O_FILE  = map_r05_to_gx1v3_roff_smooth_010718.nc
else if ($GRID == T62_gx3) then
 set MAP_A2OF_FILE = map_T62_to_gx3_aave_da_000412.nc
 set MAP_A2OS_FILE = map_T62_to_gx3_bilin_da_000412.nc
 set MAP_O2AF_FILE = map_gx3_to_T62_aave_da_000412.nc
 set MAP_R2O_FILE  = map_r05_to_gx3_roffb_b6b.c010608.nc
else if ($GRID == T85_gx1v3) then
 set MAP_A2OF_FILE = map_T85_to_gx1v3_aave_da_020405.nc
 set MAP_A2OS_FILE = map_T85_to_gx1v3_bilin_da_020405.nc
 set MAP_O2AF_FILE = map_gx1v3_to_T85_aave_da_020405.nc
 set MAP_R2O_FILE  = map_r05_to_gx1v3_roff_smooth_010718.nc
else
 echo "Using unsupported configuration, no mapping files set"
 exit 1
endif
$TOOLS/ccsm_getinput cpl/cpl5/$MAP_A2OF_FILE $MAP_A2OF_FILE || exit 1
$TOOLS/ccsm_getinput cpl/cpl5/$MAP_A2OS_FILE $MAP_A2OS_FILE || exit 1
$TOOLS/ccsm_getinput cpl/cpl5/$MAP_O2AF_FILE $MAP_O2AF_FILE || exit 1
$TOOLS/ccsm_getinput cpl/cpl5/$MAP_R2O_FILE  $MAP_R2O_FILE  || exit 1

set RUN_TYPE = $RUNTYPE
if ($RUNTYPE == startup) set RUN_TYPE = initial
if ($RUNTYPE == hybrid)  set RUN_TYPE = initial

set BASEDATE_NUM = `echo $BASEDATE | sed -e 's/-//g'`
if ($RUNTYPE == branch) then
 set REST_BFILE = $REFCASE.cpl5.r.${REFDATE}-00000
 echo  set REST_BFILE = $REST_BFILE
 $TOOLS/ccsm_getfile $REFCASE/$MODEL/rest/${REST_BFILE}  || exit 99
 set BASEDATE_NUM = `echo $REFDATE | sed -e 's/-//g'`
else
 set REST_BFILE  = 'null'
endif

echo ---------------------------------------------------------------------------
echo  b. create the namelist input file                                      
echo ---------------------------------------------------------------------------

cat >! $MODEL.stdin << EOF
  &inparm
  case_name   = '$CASE '
  case_desc   = '$CASE $CASESTR '
  rest_type   = '$RUN_TYPE '
  rest_date   =  $BASEDATE_NUM
  rest_bfile  = '${REST_BFILE} '
  rest_pfile  = '$SCRIPTS/rpointer.$MODEL'
  map_a2of_fn = '$MAP_A2OF_FILE'
  map_a2os_fn = '$MAP_A2OS_FILE'
  map_o2af_fn = '$MAP_O2AF_FILE'
  map_r2o_fn  = '$MAP_R2O_FILE'
  rest_freq    = 'monthly' 
  diag_freq    = 'monthly' 
  stop_option  = 'newmonth'
  hist_freq    = 'monthly' 
  orb_year    = 1990
  flx_epbal   = 'off'
  flx_albav   = 0
  mss_dir     = '$MSSDIR/$MODEL/ '
  mss_rtpd    =  $MSSRPD
  mss_pass    = '$MSSPWD'
  mss_rmlf    = 0
  nx_a = $ATM[2] , ny_a = $ATM[3],  nx_l = $ATM[2] , ny_l = $ATM[3]
  nx_o = $OCN[2] , ny_o = $OCN[3],  nx_i = $OCN[2] , ny_i = $OCN[3]
  /
EOF
echo o contents of $MODEL.stdin: ; cat $MODEL.stdin ; echo ' '

echo ---------------------------------------------------------------------------
echo  c. Build an executable in $OBJDIR
echo ---------------------------------------------------------------------------

cd $OBJDIR

# Filepath: List of source code directories (in order of importance).
#--------------------------------------------------------------------

\cat >! Filepath << EOF
$SCRIPTS/src.$MODEL
$CSMCODE/cpl/cpl5
$CSMSHR
EOF

# run make
#--------------------------------------------------------------------

if ($BLDTYPE == 'true') then
  cc -o makdep $CSMBLD/makdep.c                              || exit 2
  gmake -j 6 VPFILE=Filepath MODEL=cpl5 EXEC=$EXEDIR/$MODEL \
      -f  $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS    || exit 2
else
  echo "BLDTYPE = $BLDTYPE"
endif
                                         
# document the source code used, cleanup $EXEDIR/obj files
#--------------------------------------------------------------------

grep 'CVS' *.[hf]*                       
#gmake -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS mostlyclean

echo ' '
echo ===========================================================================
echo  End of setup shell script  `date` 
echo ===========================================================================
