#! /bin/csh -f
#=======================================================================
# CVS $Id: ice.setup.csh,v 1.56 2002/04/30 17:53:02 tcraig Exp $
# CVS $Source: /fs/cgd/csm/models/CVS.REPOS/scripts/test.a1/ice.setup.csh,v $
# CVS $Name: ccsm2_0_beta46 $
#=======================================================================
# ice.setup.csh: Preparing a CSM sea ice model, csim4, for execution
# 
# (a) set environment variables, preposition input data files
# (b) create the namelist input file
# (b) build this component executable
#
# For help, see:  www.ccsm.ucar.edu/models/ccsm2.0
#=======================================================================

cat $0;$TOOLS/ccsm_checkenvs || exit -1            # cat this file, check envs

echo -------------------------------------------------------------------
echo  a. set ice setup variables, get input files
echo -------------------------------------------------------------------

set PRESCRIBED_ICE      = .false.
set PRESCRIBED_ICE_CLIM = .false.
set OCEANMIXED_ICE      = .false.
set NCAT                = 5             # number of ice catagories

# Create directories for output hist/rest filenames
#-----------------------------------------------------------------------

set HSTDIR = $EXEDIR/hist ; if !(-d $HSTDIR) mkdir -p $HSTDIR
set RSTDIR = $EXEDIR/rest ; if !(-d $RSTDIR) mkdir -p $RSTDIR
set INIDIR = $EXEDIR/init ; if !(-d $INIDIR) mkdir -p $INIDIR

# Calculate year used in new hist/rest filenames
#-----------------------------------------------------------------------

if ($RUNTYPE == branch || $RUNTYPE == hybrid) then
  set DATEDASH = $REFDATE-00000
else
  set DATEDASH = $BASEDATE-00000
endif

# read in ice datasets
#-----------------------------------------------------------------------

set ICEDATA = ice/csim4/
set RESTART = .true.
set PICE_DATA = " "
set OML_ICE_SST_INIT = .false.

rm -f data.domain.grid data.domain.kmt
$TOOLS/ccsm_getinput $ICEDATA/global_${ICE_GRID}.grid data.domain.grid || exit 2
$TOOLS/ccsm_getinput $ICEDATA/global_${ICE_GRID}.kmt  data.domain.kmt  || exit 2

if ($PRESCRIBED_ICE == .true.) then
  if ($PRESCRIBED_ICE_CLIM == .false. && $BASEDATE != 1977-01-01) then
    echo "Set BASEDATE in main script to 1977-01-01" ; exit -1
  endif
  if ($RUNTYPE == startup) set RESTART = .false.
  if ($ICE_GRID == 'gx3') \
      set PICE_DATA = AMIP_bc${ICE_GRID}_1976-1996_011030.nc
  if ($ICE_GRID == 'gx1v3') \
      set PICE_DATA = AMIP_bc${ICE_GRID}_1976-1996_010817.nc
  $TOOLS/ccsm_getinput $ICEDATA/$PICE_DATA . || exit 99
endif

if ($RESTART == .true.) then
  if ($RUNTYPE == startup  ) then
      set RSTFILE = iced.0001-01-01.${ICE_GRID}
      $TOOLS/ccsm_getinput $ICEDATA/$RSTFILE $RSTDIR/ || exit 2
      echo $RSTDIR/$RSTFILE >! $SCRIPTS/rpointer.ice
  else if ($RUNTYPE == branch || $RUNTYPE == hybrid) then
      set RSTFILE = $REFCASE.csim.r.$DATEDASH
      $TOOLS/ccsm_getfile $REFCASE/ice/rest/$RSTFILE $RSTDIR/ || exit 2
      echo $RSTDIR/$RSTFILE >! $SCRIPTS/rpointer.ice
  endif
endif

if ($OCEANMIXED_ICE == .true. ) then
  $TOOLS/ccsm_getinput $ICEDATA/pop_frc_${ICE_GRID}_010815.nc oceanmixed_ice.nc || exit 99
  if ($RUNTYPE == startup) set OML_ICE_SST_INIT = .true.
  if ( $PRESCRIBED_ICE == .true.) then
    echo " Prescribed_ice cannot have Oceanmixed_ice  -stop-" ; exit -1
  endif
endif

echo -------------------------------------------------------------------
echo  b. create the namelist input file                                      
echo -------------------------------------------------------------------

cat << EOF >! ice_in
  &ice_nml
    runid        = '$CASE $CASESTR'
  , runtype      = '$RUNTYPE'
  , istep0       = 0
  , dt           = 3600.0
  , ndte         = 120
  , npt          = 99999
  , diagfreq     = 24
  , histfreq     = 'm'
  , dumpfreq     = 'y'
  , hist_avg     = .true.
  , restart      = $RESTART
  , print_points = .false.
  , kitd         = 1
  , kdyn         = 1
  , kstrength    = 1
  , evp_damping  = .false.
  , snow_into_ocn = .false.
  , advection    = 'mpdata2'
  , grid_type    = 'displaced_pole'
  , grid_file    = 'data.domain.grid'
  , kmt_file     = 'data.domain.kmt'
  , incond_dir   = '$INIDIR/'
  , incond_file  = '$CASE.csim.i.'
  , restart_dir  = '$RSTDIR/'
  , dump_file    = '$CASE.csim.r.'
  , history_dir  = '$HSTDIR/'
  , history_file = '$CASE.csim.h'
  , mss_dir      = '$MSSDIR/$MODEL/ '
  , mss_rtpd     =  $MSSRPD
  , mss_pass     = '$MSSPWD'
  , mss_rmlf     = 0
  , prescribed_ice             = $PRESCRIBED_ICE
  , prescribed_ice_file        = '$PICE_DATA'
  , prescribed_ice_climatology = $PRESCRIBED_ICE_CLIM
  , pointer_file  = '$SCRIPTS/rpointer.$MODEL'
  , oceanmixed_ice             = $OCEANMIXED_ICE
  , oceanmixed_ice_file        = 'oceanmixed_ice.nc'
  , oceanmixed_ice_sst_init    = $OML_ICE_SST_INIT
  , prntdiag_oceanmixed        = .false.
/

  &icefields_nml
    f_Fswdn   = .false.
  , f_Flwdn   = .false.
  , f_snow    = .false.
  , f_rain    = .false.
  , f_sst     = .false.
  , f_sss     = .false.
  , f_uocn    = .false.
  , f_vocn    = .false.
  , f_frzmlt  = .false.
  , f_strtltx = .false.
  , f_strtlty = .false.
  , f_Tref    = .false.
  /
EOF
echo o contents of $MODEL.stdin: ; cat $MODEL.stdin ; echo ' '

echo -------------------------------------------------------------------
echo  c. Build an executable in $OBJDIR 
echo -------------------------------------------------------------------

cd $OBJDIR

# Filepath: List of source code directories (in order of importance).
#-----------------------------------------------------------------------

\cat >! Filepath << EOF
$SCRIPTS/src.$MODEL
$CSMCODE/ice/csim4/src/source
$CSMSHR
EOF

# select resolution
#-----------------------------------------------------------------------
if ( $GRID =~ *gx3)   set RES = 100x116
if ( $GRID =~ *hx1)   set RES = 384x320
if ( $GRID =~ *gx1v3) set RES = 320x384
if !($?RES)   echo "ERROR: ice can't deal with GRID = $GRID" 
if !($?RES)   exit -1

set NLON = `echo $RES | sed s/x.\*//`
set NLAT = `echo $RES | sed s/.\*x//`

# Calculate processor tiling based on $NTASK
#-----------------------------------------------------------------------
@ nlon = $NLON
setenv NY 1
if ($NTASK > 16) setenv NY 2
@ nx  = $NTASK / $NY ; setenv NX $nx
@ rem = $nlon % $nx
if ($rem != 0) echo ERROR: NX must divide evenly into grid, $NLON,$NX
if ($rem != 0) exit -1

# Wipe and rebuild if NX or NY have changed
#-----------------------------------------------------------------------
echo $NX $NY  >! NXNY.new
cmp -s  NXNY.old NXNY.new || rm $OBJDIR/*.o $EXEDIR/ice
echo $NX $NY  >! NXNY.old

# Position new ice_model_size.F when needed
#-----------------------------------------------------------------------
set ICESRC =  $CSMCODE/ice/csim4/src/input_templates
cmp -s $ICESRC/ice_model_size.F.${RES}x${NCAT} ice_model_size.F || \
    cp $ICESRC/ice_model_size.F.${RES}x${NCAT} ice_model_size.F || exit 3

# run make
#-----------------------------------------------------------------------

if ($BLDTYPE == 'true') then
  cc -o makdep $CSMBLD/makdep.c                              || exit 2
  if ($NTHRD > 1) setenv THREAD TRUE
  gmake -j 6 VPFILE=Filepath MODEL=csim EXEC=$EXEDIR/$MODEL \
             NX=$NX NY=$NY THREAD=$THREAD \
        -f  $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS    || exit 2
else
  echo "BLDTYPE = $BLDTYPE"
endif
                                         
# document the source code used, cleanup $OBJDIR files
#-----------------------------------------------------------------------

grep 'CVS' *.[hf]*                       
#gmake -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS mostlyclean

echo ' '
echo -------------------------------------------------------------------
echo  End of setup shell script  `date` 
echo -------------------------------------------------------------------
