#! /bin/csh -f
#===============================================================================
# CVS $Id: latm.setup.csh,v 1.13 2002/05/08 03:04:12 tcraig Exp $
# CVS $Source: /fs/cgd/csm/models/CVS.REPOS/scripts/test.a1/latm.setup.csh,v $
# CVS $Name: ccsm2_0_beta46 $
#===============================================================================
# latm.setup.csh: Prepare a CSM data atmosphere component, latm5, for execution
#                 For help, see:  www.ccsm.ucar.edu/models/ccsm2.0
#===============================================================================

cat $0;$TOOLS/ccsm_checkenvs || exit -1            # cat this file, check envs

echo ---------------------------------------------------------------------------
echo  a. set environment variables, preposition input data files             
echo ---------------------------------------------------------------------------

if ( $ATM_GRID != 'T62') then  
  echo "ERROR: can't deal with GRID=$ATM_GRID"  ; exit -1
endif

set RUN_TYPE = $RUNTYPE
if ($RUNTYPE == startup) set RUN_TYPE = initial

echo ---------------------------------------------------------------------------
echo  b. create the namelist input file                                      
echo ---------------------------------------------------------------------------

# All NCEP input
# get input data files for first year
$TOOLS/ccsm_getinput atm/latm5/dn10.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/prec.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/q_10.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/swdn.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/swup.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/lwdn.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/t_10.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/u_10.1985.nc  || exit 99
$TOOLS/ccsm_getinput atm/latm5/v_10.1985.nc  || exit 99

set DATA_DIR = mss:/CSM/DATA/ATM/T62/NCEP/4XDAILY
#set DATA_DIR = cp:$CSMDATA/atm/latm5

cat >! atm.stdin << EOF
 &inparm
 case_name     = '$CASE'
 case_desc     = '$CASE $CASESTR'
 rest_type     = '$RUN_TYPE '
 data_dir(1)   = '$DATA_DIR/STATES'
 data_year0(1) = 1985
 data_oyear(1) =    1
 data_nyear(1) =    1
 data_dir(2)   = '$DATA_DIR/PRECIP'
 data_year0(2) = 1985
 data_oyear(2) =    1
 data_nyear(2) =    1
 data_dir(3)   = '$DATA_DIR/RADFLX'
 data_year0(3) = 1985
 data_oyear(3) =    1
 data_nyear(3) =    1
 ncpl          =   24
 flux_albfb    =    1
 flux_lwfb     =    1
 /
EOF

echo ---------------------------------------------------------------------------
echo  c. Build an executable in $OBJDIR
echo ---------------------------------------------------------------------------

# Filepath: List of source code directories (in order of importance).
#--------------------------------------------------------------------

cd $OBJDIR

\cat >! Filepath << EOF
$SCRIPTS/src.$MODEL
$CSMCODE/atm/latm5
$CSMSHR
EOF

# Check to see if a new dims.h is needed.

cmp -s $CSMCODE/atm/latm5/dims.h.$ATM_GRID dims.h || \
    cp $CSMCODE/atm/latm5/dims.h.$ATM_GRID dims.h  || exit 3


# run make
#--------------------------------------------------------------------

if ($BLDTYPE == 'true') then
  cc -o makdep $CSMBLD/makdep.c                              || exit 2
  if ($NTHRD > 1) setenv THREAD TRUE
  gmake -j 6 VPFILE=Filepath MODEL=latm EXEC=$EXEDIR/$MODEL \
      -f  $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS    || exit 2
else
  echo "BLDTYPE = $BLDTYPE"
endif
                                         
# document the source code used, cleanup $OBJDIR files
#--------------------------------------------------------------------

grep 'CVS' *.[hf]*                       
#gmake -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS mostlyclean

echo ' '
echo ===========================================================================
echo  End of setup shell script  `date` 
echo ===========================================================================
