#! /bin/csh -f
#===============================================================================
# CVS $Id: lnd.setup.csh,v 1.43 2002/05/13 20:25:52 tcraig Exp $
# CVS $Source: /fs/cgd/csm/models/CVS.REPOS/scripts/test.a1/lnd.setup.csh,v $
# CVS $Name: ccsm2_0_beta46 $
#===============================================================================
# lnd.setup.csh: Preparing a CCSM Common Land Model, clm2, for execution
# 
# (a) set environment variables, preposition input data files
# (b) create the namelist input file
# (b) build this component executable
#
# For help, see:  www.ccsm.ucar.edu/models/ccsm2.0
#===============================================================================

cat $0;$TOOLS/ccsm_checkenvs || exit -1            # cat this file, check envs

echo ---------------------------------------------------------------------------
echo  a. set environment variables, preposition input data files             
echo ---------------------------------------------------------------------------

# lnd source code archive
#------------------------
set SRCDIR = $CSMCODE/lnd/clm2/src
set CAMLND_SHARE = $CSMCODE/camclm_share

cd $EXEDIR

# Set restart type
#------------------------------------------------
if ($RUNTYPE == 'startup')  then
 set NSREST = 0
 set NREVSN = ""
 if ($GRID =~ T42* )  then
  set DATINIT = Ba.b19.clmi_00030101_00000.nc
  $TOOLS/ccsm_getinput lnd/clm2/inidata/csm/$DATINIT || exit 99
  if !(-f $DATINIT) exit 99 
 else
  set DATINIT = ""
 endif
else if ($RUNTYPE == 'continue')  then
 set NSREST = 1
 set DATINIT = ""
 set NREVSN = ""
else if ($RUNTYPE == 'branch' )  then
 set NSREST = 3
 set DATINIT = ""
 set NREVSN = ${REFCASE}.clm2.r.${REFDATE}-00000
 $TOOLS/ccsm_getfile $REFCASE/lnd/rest/$NREVSN || exit 99
 if !(-f $NREVSN) exit 99 
else if ($RUNTYPE == 'hybrid')  then
 set NSREST = 0
 set NREVSN = ""
 set DATINIT = ${REFCASE}.clm2.i.${REFDATE}-00000.nc
 $TOOLS/ccsm_getfile $REFCASE/lnd/init/$DATINIT || exit 99
 if !(-f $DATINIT) exit 99 
endif

# Position the input data
#------------------------------------------------
set data_dir  = lnd/clm2

if ($ATM_GRID == 'T85') set atmres = '256x128'
if ($ATM_GRID == 'T42') set atmres = '128x064'
if ($ATM_GRID == 'T31') set atmres = '096x048'
if ($ATM_GRID == 'T85') set DTIME  =  600
if ($ATM_GRID == 'T42') set DTIME  = 1200
if ($ATM_GRID == 'T31') set DTIME  = 1800
if ($ATM_GRID == 'T85') set RTM_NSTEPS = 18
if ($ATM_GRID == 'T42') set RTM_NSTEPS = 9
if ($ATM_GRID == 'T31') set RTM_NSTEPS = 6

set surf_dat_date = ""
if ($atm_setup == atm && $ATM_GRID == 'T42') set surf_dat_date = ".080101"
set surf_dat = surface-data.${atmres}_${atm_setup}.${OCN_GRID}_ocn${surf_dat_date}.nc

$TOOLS/ccsm_getinput $data_dir/pftdata/pft-physiology               || exit 1
$TOOLS/ccsm_getinput $data_dir/rtmdata/rdirc.05                     || exit 1
if ("$surf_dat" != "") then
  $TOOLS/ccsm_getinput $data_dir/srfdata/csm/$surf_dat              || exit 1
else									   
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_soicol_clm2.nc       || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_lanwat.nc            || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_glacier.nc           || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_urban.nc             || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_lai.nc               || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_pft.nc               || exit 1
  $TOOLS/ccsm_getinput $data_dir/rawdata/mksrf_soitex.10level.nc    || exit 1
endif


set BASEDATE_NUM = `echo $BASEDATE | sed -e 's/-//g'`  # remove "-"

# Create the input parameter namelist file                          '
#------------------------------------------------
cat >! lnd.stdin << EOF
 &clmexp
 rtm_nsteps       =  $RTM_NSTEPS
 caseid           = '$CASE'
 ctitle           = '$CASE $CASESTR'  
 nsrest           =  $NSREST
 start_ymd        =  $BASEDATE_NUM
 start_tod        =  0
 nelapse          = -9999    
 dtime            =  $DTIME
 irad             = -1
 csm_doflxave     = .true.
 nrevsn           = '$NREVSN '
 finidat          = '$DATINIT '
 fsurdat          = '$surf_dat'
 fpftcon          = 'pft-physiology'
 frivinp_rtm      = 'rdirc.05'
 mksrf_fvegtyp    = 'mksrf_pft.nc'
 mksrf_fsoitex    = 'mksrf_soitex.10level.nc'
 mksrf_fsoicol    = 'mksrf_soicol_clm2.nc'
 mksrf_flanwat    = 'mksrf_lanwat.nc'
 mksrf_fglacier   = 'mksrf_glacier.nc'
 mksrf_furban     = 'mksrf_urban.nc'
 mksrf_flai       = 'mksrf_lai.nc'
 mss_wpass        = '$MSSPWD'
 hist_nhtfrq      =  0
 hist_crtinic     = 'YEARLY'
 mss_irt         =  $MSSRPD
 rpntpath         = '$SCRIPTS/rpointer.$MODEL'
 /
EOF


echo '-------------------------------------------------------------------------'
echo  b. Build an executable in $OBJDIR
echo '-------------------------------------------------------------------------'

cd $OBJDIR

# build Filepath: List of source code directories (in order of importance) 
# (update only if new or changed)
#--------------------------------------------------------------------
\cat >! .tmp << EOF; cmp -s .tmp Filepath || mv -f .tmp Filepath
$SCRIPTS/src.lnd
$SRCDIR/main
$SRCDIR/biogeophys
$SRCDIR/ecosysdyn
$SRCDIR/riverroute
$SRCDIR/biogeochem
$SRCDIR/mksrfdata
$CAMLND_SHARE
$CSMSHR
$CSMCODE/utils/timing
EOF

# build preproc.h: land model dimensions 
# (update only if new or changed)
#----------------------------------------------------------
if ($GRID =~ T85* )  set LONLAT = ( 256 128 )
if ($GRID =~ T42* )  set LONLAT = ( 128 64 )
if ($GRID =~ T31* )  set LONLAT = (  96 48 )

\cat >! .tmp << EOF; cmp -s .tmp preproc.h || mv -f .tmp preproc.h
#ifndef PREPROC_SET
#define PREPROC_SET
#define LSMLON $LONLAT[1]
#define LSMLAT $LONLAT[2]
#endif
EOF

# build misc.h    
# (update only if new or changed)
#------------------------------------------------
set spmd = "#undef  SPMD"
if ($NTASK > 1) set spmd = "#define SPMD"   

\cat >! .tmp << EOF; cmp -s .tmp misc.h || mv -f .tmp misc.h
#ifndef MISC_SET  
#define MISC_SET  
$spmd
#define COUP_CSM
#define RTM    
#endif       
EOF

# Create the executable
#----------------------
if ($BLDTYPE == 'true') then
  set echo on
  cc -o makdep $CSMBLD/makdep.c
  if ($NTHRD > 1) setenv THREAD TRUE
  gmake -j 6 -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS MODEL=clm  \
                 VPFILE=Filepath EXEC=$EXEDIR/lnd || exit 2
else
  echo "BLDTYPE = $BLDTYPE"
endif
wait

echo ==================================================================
echo  End of clm2 model setup shell script
echo ==================================================================
