#! /bin/csh -fv
#===============================================================================
#===============================================================================
# Purpose:
#  (a) build an executable model (pop, a CSM active ocn component)
#  (b) gather or create necessary input files
#
# For help, see:  www.ccsm.ucar.edu/models/ccsm2.0
#===============================================================================
cat $0;$TOOLS/ccsm_checkenvs || exit -1            # cat this file, check envs

echo -----------------------------------------------------------------
echo  setting up some internal Env variables and path names
echo -----------------------------------------------------------------



set SRCDIR  = $CSMCODE/ocn/pop
set my_path = $SCRIPTS/src.ocn


if ( $OCN_GRID ==  gx1v3) then
  setenv DT_COUNT  23
  setenv TIME_MIX_FREQ 17
  setenv INIT_TS_FILE ts_PHC2_jan_20010711

else if ( $OCN_GRID ==  gx3) then
  setenv DT_COUNT  12
  setenv TIME_MIX_FREQ 100
  setenv INIT_TS_FILE ts_PHC2_jan_20011012

else
  echo "$0 ERROR: Cannot deal with GRID = $GRID"
  exit -1
endif


# branch- or hybrid-run setup
#---------------------------------------------
if ($RUNTYPE == branch || $RUNTYPE == hybrid) then
  setenv INIT_TS_FILE ${REFCASE}.pop.r.$REFDATE-00000
  setenv TAVG_TS_FILE ${REFCASE}.pop.rh.$REFDATE-00000

# position the branch or hybrid files
  if !(-d rest ) mkdir -p rest
  cd rest
  $TOOLS/ccsm_getfile  $REFCASE/ocn/rest/$INIT_TS_FILE     || exit 99
  $TOOLS/ccsm_getfile  $REFCASE/ocn/rest/$INIT_TS_FILE.hdr || exit 99
  $TOOLS/ccsm_getfile  $REFCASE/ocn/rest/$TAVG_TS_FILE     || exit 99
  $TOOLS/ccsm_getfile  $REFCASE/ocn/rest/$TAVG_TS_FILE.hdr || exit 99
  cd ..

# generate the appropriate restart pointer files
cat >! $SCRIPTS/rpointer.ocn.restart << EOF
$cwd/rest/$INIT_TS_FILE.hdr
$cwd/rest/$INIT_TS_FILE
EOF

cat >! $SCRIPTS/rpointer.ocn.tavg << EOF
$cwd/rest/$TAVG_TS_FILE.hdr
$cwd/rest/$TAVG_TS_FILE
EOF

endif

echo -------------------------------------------------------------------------
echo  a. Build an executable in $OBJDIR
echo -------------------------------------------------------------------------

if ( -e ocn && $?DONTBUILD ) then
  echo "Note: using an existing binary"
else

  echo -------------------------------------------------------------------------
  echo  a.1 Calculate processor tiling based on $NTASK
  echo -------------------------------------------------------------------------
  if ($NTASK ==  4)   setenv NX  2
  if ($NTASK ==  8)   setenv NX  4
  if ($NTASK == 16)   setenv NX  4
  if ($NTASK == 32)   setenv NX  8
  if ($NTASK == 40)   setenv NX  5
  if ($NTASK == 48)   setenv NX  8
  if ($NTASK == 64)   setenv NX  8
  if !($?NX)          echo ERROR: ocn cant deal with NTASK=$NTASK
  if !($?NX)          exit -1
  @ ny = $NTASK / $NX; setenv NY $ny

  echo -----------------------------------------------------------------
  echo  a2. creating the internal directory structure
  echo -----------------------------------------------------------------

  set compile_dir = $OBJDIR/compile
  set source_dir  = $OBJDIR/source
  if !(-d $source_dir  ) mkdir -p $source_dir
  if !(-d $compile_dir ) mkdir -p $compile_dir

  echo ' '
  echo '-----------------------------------------------------------------'
  echo ' copy the necessary files into $source_dir                       '
  echo '-----------------------------------------------------------------'
  cd $source_dir
  cp -fp $SRCDIR/input_templates/${OCN_GRID}_model_size.F model_size.F
  cp -fp $SRCDIR/source/*.[FCc]             .
  cp -fp $SRCDIR/mpi/*.[FCc]                .
  cp -fp $CSMSHR/*.[F]*                   .
  cp -fp $CSMSHR/*.[Cc]                   .
  if (-d $my_path ) cp -fp $my_path/*.[FCc] .
#
#  recompile if 2d decomp is changed
#
  echo $OCN_GRID $NTASK $NX $NY >! $OBJDIR/ocnres.new
  diff $OBJDIR/ocnres.new $OBJDIR/ocnres.old || touch `grep -l NPROC $OBJDIR/source/*`  # force recompile
  echo $OCN_GRID $NTASK $NX $NY >! $OBJDIR/ocnres.old

  echo -----------------------------------------------------------------
  echo  a3. compile and copy the executable into $EXEDIR directory
  echo -----------------------------------------------------------------

  if ($BLDTYPE == 'true') then
    cd $compile_dir

    cc -o makdep $CSMBLD/makdep.c  || exit 2

    set EXEC = ocn_${NTASK}
    set THREAD = FALSE ; if ($NTHRD > 1) set THREAD = TRUE
    gmake -j 6 -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS \
	MODEL=pop NX=$NX NY=$NY THREAD=$THREAD                \
        VPATH=$source_dir EXEC=$OBJDIR/$EXEC                  || exit 2

# gmake -f $CSMBLD/Makefile MACFILE=$CSMBLD/Macros.$OS mostlyclean

  #--- cp & link into EXEDIR ---
    rm -f $EXEDIR/ocn
    cp $OBJDIR/$EXEC  $EXEDIR/ocn
  else
    echo "BLDTYPE = $BLDTYPE"
  endif

endif

echo ' '
echo '-------------------------------------------------------------------------'
echo " b. gather or create necessary input files in $EXEDIR                   "
echo '-------------------------------------------------------------------------'

set IYEAR0        = `echo $BASEDATE | cut -c1-4  | sed -e 's/^0*//'`
set IMONTH0       = `echo $BASEDATE | cut -c6-7  | sed -e 's/^0*//'`
set IDAY0         = `echo $BASEDATE | cut -c9-10 | sed -e 's/^0*//'`

if ($RUNTYPE == startup || $RUNTYPE == hybrid  )  @ IDAY0 = $IDAY0 + 1



# sed commands are of the form  s#OldString#NewString#

cat >! $EXEDIR/commands.sed << EOF
s#OUTPUTL#$EXEDIR#
s#OUTPUTR#$EXEDIR/rest/$CASE.pop.r#
s#OUTPUTH#$EXEDIR/hist/$CASE.pop.h#
s#OUTPUTD#$EXEDIR/hist/$CASE.pop.d#
s#OUTPUT/pop_pointer#$SCRIPTS/rpointer.ocn#

s#RUNID#$CASE#;                  s#LOG_FILENAME#$ocn_out#
s#INIT_TS_OPTION#$RUNTYPE#
s#INPUT#$EXEDIR/input#
s#DT_COUNT#$DT_COUNT#;           s#TIME_MIX_FREQ#$TIME_MIX_FREQ#

s#IYEAR0#$IYEAR0#;               s#IHOUR0#0#
s#IMONTH0#$IMONTH0#;             s#IMINUTE0#0#
s#IDAY0#$IDAY0#;                 s#ISECOND0#0#

EOF

sed -f $EXEDIR/commands.sed $SRCDIR/input_templates/${OCN_GRID}_pop_in >! $EXEDIR/pop_in  || exit 3

# put pop_in where pop can find it (specific to mpirun, poe, etc)
ln -sf $EXEDIR/pop_in $EXEDIR/..
if (-d $EXEDIR/../all) ln -sf $EXEDIR/pop_in $EXEDIR/../all

echo '-------------------------------------------------------------------------'
echo   c. cp input datasets from $SRCDIR ...
echo '-------------------------------------------------------------------------'

if !( -d $EXEDIR/rest  )  mkdir -p $EXEDIR/rest   || exit 2
if !( -d $EXEDIR/hist  )  mkdir -p $EXEDIR/hist   || exit 2
if !( -d $EXEDIR/input )  mkdir -p $EXEDIR/input  || exit 2

cd $EXEDIR/input

foreach FILE (depth_accel history_contents \
              movie_contents region_ids  scalar_contents tavg_contents \
              transport_contents vert_grid )
  $TOOLS/ccsm_cpdata $SRCDIR/input_templates/${OCN_GRID}_$FILE $FILE || exit 99
end
foreach FILE (eos_coefficients.ieeer8 )
  $TOOLS/ccsm_cpdata $SRCDIR/input_templates/${OCN_GRID}_$FILE $FILE
end

echo '-------------------------------------------------------------------------'
echo   c. acquire initial/boundary datasets disk or MSS
echo '-------------------------------------------------------------------------'

set OCNDATA = ocn/pop/$OCN_GRID  # point to disk copies

if ($RUNTYPE == startup ) then
$TOOLS/ccsm_getinput $OCNDATA/ic/${INIT_TS_FILE}.ieeer8         ts                  || exit 99
$TOOLS/ccsm_getinput $OCNDATA/ic/${INIT_TS_FILE}.readme         ts.readme           || exit 99
endif 
 
if ($OCN_GRID == gx1v3) then 
 $TOOLS/ccsm_getinput $OCNDATA/grid/horiz_grid_20010402.ieeer8   horiz_grid         || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/horiz_grid_20010402.readme   horiz_grid.readme  || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/region_mask_20010709.ieeei4  region_mask        || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/region_mask_20010709.readme  region_mask.readme || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/topography_20010702.ieeei4   topography         || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/topography_20010702.readme   topography.readme  || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/shf_mm_all_85-88_20010308.ieeer8  shf        || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/shf_mm_all_85-88_20010308.readme  shf.readme || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/sfwf_mm_all_85-88_20010320.readme shf.readme || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/sfwf_mm_all_85-88_20010320.ieeer8 sfwf       || exit 99

else if ($OCN_GRID == gx3) then
 $TOOLS/ccsm_getinput $OCNDATA/grid/horiz_grid_20001030.ieeer8 	 horiz_grid         || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/horiz_grid_20001030.readme 	 horiz_grid.readme  || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/region_mask_20001030.ieeei4  region_mask        || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/region_mask_20001030.readme  region_mask.readme || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/topography_20001030.ieeei4   topography         || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/grid/topography_20001030.readme   topography.readme  || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/shf_20011030.ieeer8       shf                || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/shf_20011030.readme       shf.readme         || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/sfwf_20011030.ieeer8      sfwf               || exit 99
 $TOOLS/ccsm_getinput $OCNDATA/forcing/sfwf_20011030.readme      sfwf.readme        || exit 99


endif

wait

unset echo

echo ' '
echo '-----------------------------------------------------------------'
echo ' End of setup shell script                                       '
echo '-----------------------------------------------------------------'


exit


